@@ -224,14 +224,6 @@ import os
 import sys
 import fcntl
 
-from duplicity import log
-
-try:
-    import threading
-except ImportError:
-    import dummy_threading
-    log.Warn("Threading not available -- zombie processes may appear")
-
 __author__   = "Frank J. Tobin, ftobin@neverending.org"
 __version__  = "0.3.2"
 __revision__ = "$Id: GnuPGInterface.py,v 1.6 2009/06/06 17:35:19 loafman Exp $"
@@ -405,12 +397,6 @@ class GnuPG:
             process._pipes[fh_name] = Pipe(fh.fileno(), fh.fileno(), 1)
 
         process.pid = os.fork()
-        if process.pid != 0:
-            # start a threaded_waitpid on the child
-            process.thread = threading.Thread(target=threaded_waitpid,
-                                              name="wait%d" % process.pid,
-                                              args=(process,))
-            process.thread.start()
 
         if process.pid == 0: self._as_child(process, gnupg_commands, args)
         return self._as_parent(process)
@@ -639,37 +625,21 @@ class Process:
     """
 
     def __init__(self):
-        self._pipes   = {}
-        self.handles  = {}
-        self.pid      = None
-        self._waited  = None
-        self.thread   = None
-        self.returned = None
+        self._pipes  = {}
+        self.handles = {}
+        self.pid     = None
+        self._waited = None
 
     def wait(self):
-        """
-        Wait on threaded_waitpid to exit and examine results.
-        Will raise an IOError if the process exits non-zero.
-        """
-        if self.returned == None:
-            self.thread.join()
-        if self.returned != 0:
-            raise IOError, "GnuPG exited non-zero, with code %d" % (self.returned >> 8)
-
-
-def threaded_waitpid(process):
-    """
-    When started as a thread with the Process object, thread
-    will execute an immediate waitpid() against the process
-    pid and will collect the process termination info.  This
-    will allow us to reap child processes as soon as possible,
-    thus freeing resources quickly.
-    """
-    process.returned = os.waitpid(process.pid, 0)[1]
+        """Wait on the process to exit, allowing for child cleanup.
+        Will raise an IOError if the process exits non-zero."""
 
+        e = os.waitpid(self.pid, 0)[1]
+        if e != 0:
+            raise IOError, "GnuPG exited non-zero, with code %d" % (e >> 8)
 
 def _run_doctests():
-    import doctest, GnuPGInterface
+    import doctest, GnuPGInterface #@UnresolvedImport
     return doctest.testmod(GnuPGInterface)
 
 # deprecated
