@@ -66,7 +66,9 @@ class GPGProfile:
             assert recipients # can only sign with asym encryption
 
         self.passphrase = passphrase
+        self.signing_passphrase = passphrase
         self.sign_key = sign_key
+        self.encrypt_secring = None
         if recipients is not None:
             assert type(recipients) is types.ListType # must be list, not tuple
             self.recipients = recipients
@@ -95,6 +97,7 @@ class GPGFile:
         self.closed = None # set to true after file closed
         self.logger_fp = tempfile.TemporaryFile()
         self.stderr_fp = tempfile.TemporaryFile()
+        self.name = encrypt_path
 
         # Start GPG process - copied from GnuPGInterface docstring.
         gnupg = GnuPGInterface.GnuPG()
@@ -110,6 +113,17 @@ class GPGFile:
         if profile.sign_key:
             gnupg.options.default_key = profile.sign_key
             cmdlist.append("--sign")
+        # encrypt: sign key needs passphrase
+        # decrypt: encrypt key needs passphrase
+        # special case: allow different symmetric pass with empty sign pass
+        if encrypt and profile.sign_key and profile.signing_passphrase:
+            passphrase = profile.signing_passphrase
+        else:
+            passphrase = profile.passphrase
+        # in case the passphrase is not set, pass an empty one to prevent
+        # TypeError: expected a character buffer object on .write()
+        if passphrase is None:
+            passphrase = ""
 
         if encrypt:
             if profile.recipients:
@@ -123,17 +137,20 @@ class GPGFile:
                            attach_fhs={'stdout': encrypt_path.open("wb"),
                                        'stderr': self.stderr_fp,
                                        'logger': self.logger_fp})
-            p1.handles['passphrase'].write(profile.passphrase)
+            p1.handles['passphrase'].write(passphrase)
             p1.handles['passphrase'].close()
             self.gpg_input = p1.handles['stdin']
         else:
+            if profile.recipients and profile.encrypt_secring:
+                cmdlist.append('--secret-keyring')
+                cmdlist.append(profile.encrypt_secring)
             self.status_fp = tempfile.TemporaryFile()
             p1 = gnupg.run(['--decrypt'], create_fhs=['stdout', 'passphrase'],
                            attach_fhs={'stdin': encrypt_path.open("rb"),
                                        'status': self.status_fp,
                                        'stderr': self.stderr_fp,
                                        'logger': self.logger_fp})
-            p1.handles['passphrase'].write(profile.passphrase)
+            p1.handles['passphrase'].write(passphrase)
             p1.handles['passphrase'].close()
             self.gpg_output = p1.handles['stdout']
         self.gpg_process = p1
@@ -149,7 +166,7 @@ class GPGFile:
     def write(self, buf):
         try:
             res = self.gpg_input.write(buf)
-        except:
+        except Exception:
             self.gpg_failed()
         return res
 
@@ -170,13 +187,13 @@ class GPGFile:
         if self.encrypt:
             try:
                 self.gpg_input.close()
-            except:
+            except Exception:
                 self.gpg_failed()
             if self.status_fp:
                 self.set_signature()
             try:
                 self.gpg_process.wait()
-            except:
+            except Exception:
                 self.gpg_failed()
         else:
             res = 1
@@ -184,17 +201,17 @@ class GPGFile:
                 # discard remaining output to avoid GPG error
                 try:
                     res = self.gpg_output.read(blocksize)
-                except:
+                except Exception:
                     self.gpg_failed()
             try:
                 self.gpg_output.close()
-            except:
+            except Exception:
                 self.gpg_failed()
             if self.status_fp:
                 self.set_signature()
             try:
                 self.gpg_process.wait()
-            except:
+            except Exception:
                 self.gpg_failed()
         self.logger_fp.close()
         self.stderr_fp.close()
